@@ -51,7 +51,7 @@
 /*
  * Public API
  */
-Local::Heap::Heap (Ekiga::ServiceCore &_core): core (_core), doc (NULL)
+Local::Heap::Heap (Ekiga::ServiceCore &_core): core (_core), doc ()
 {
   xmlNodePtr root;
   gchar *c_raw = gm_conf_get_string (KEY);
@@ -60,13 +60,15 @@ Local::Heap::Heap (Ekiga::ServiceCore &_core): core (_core), doc (NULL)
   if (c_raw != NULL) {
 
     const std::string raw = c_raw;
-    doc = xmlRecoverMemory (raw.c_str (), raw.length ());
+    doc = std::tr1::shared_ptr<xmlDoc> (xmlRecoverMemory (raw.c_str (), raw.length ()), xmlFreeDoc);
+    if ( !doc)
+      doc = std::tr1::shared_ptr<xmlDoc> (xmlNewDoc (BAD_CAST "1.0"), xmlFreeDoc);
 
-    root = xmlDocGetRootElement (doc);
+    root = xmlDocGetRootElement (doc.get ());
     if (root == NULL) {
 
-      root = xmlNewDocNode (doc, NULL, BAD_CAST "list", NULL);
-      xmlDocSetRootElement (doc, root);
+      root = xmlNewDocNode (doc.get (), NULL, BAD_CAST "list", NULL);
+      xmlDocSetRootElement (doc.get (), root);
     }
 
     for (xmlNodePtr child = root->children; child != NULL; child = child->next)
@@ -81,9 +83,9 @@ Local::Heap::Heap (Ekiga::ServiceCore &_core): core (_core), doc (NULL)
   }
   else {
 
-    doc = xmlNewDoc (BAD_CAST "1.0");
-    root = xmlNewDocNode (doc, NULL, BAD_CAST "list", NULL);
-    xmlDocSetRootElement (doc, root);
+    doc = std::tr1::shared_ptr<xmlDoc> (xmlNewDoc (BAD_CAST "1.0"), xmlFreeDoc);
+    root = xmlNewDocNode (doc.get (), NULL, BAD_CAST "list", NULL);
+    xmlDocSetRootElement (doc.get (), root);
 
     {
       // add 500 and 501 at ekiga.net in this case!
@@ -99,8 +101,6 @@ Local::Heap::Heap (Ekiga::ServiceCore &_core): core (_core), doc (NULL)
 
 Local::Heap::~Heap ()
 {
-  if (doc != NULL)
-    xmlFreeDoc (doc);
 }
 
 
@@ -129,39 +129,84 @@ Local::Heap::populate_menu_for_group (const std::string name,
   return true;
 }
 
+struct has_presentity_with_uri_helper
+{
+  has_presentity_with_uri_helper (const std::string uri_): uri(uri_),
+							   found(false)
+  {}
+
+  const std::string uri;
+
+  bool found;
+
+  bool test (Local::PresentityPtr presentity)
+  {
+    if (presentity->get_uri () == uri) {
+
+      found = true;
+    }
+
+    return !found;
+  }
+};
 
 bool
 Local::Heap::has_presentity_with_uri (const std::string uri)
 {
-  bool result = false;
+  has_presentity_with_uri_helper helper(uri);
 
-  for (iterator iter = begin ();
-       iter != end () && result != true;
-       iter++)
-    result = ((*iter)->get_uri () == uri);
+  visit_presentities (sigc::mem_fun (helper, &has_presentity_with_uri_helper::test));
 
-  return result;
+  return helper.found;
 }
 
+struct existing_groups_helper
+{
+  std::set<std::string> groups;
+
+  bool test (Local::PresentityPtr presentity)
+  {
+    const std::set<std::string> presentity_groups = presentity->get_groups ();
+
+    groups.insert (presentity_groups.begin (),
+		   presentity_groups.end ());
+
+    return true;
+  }
+};
 
 const std::set<std::string>
 Local::Heap::existing_groups ()
 {
   std::set<std::string> result;
 
-  for (iterator iter = begin ();
-       iter != end ();
-       iter++) {
+  {
+    existing_groups_helper helper;
 
-    std::set<std::string> groups = (*iter)->get_groups ();
-    result.insert (groups.begin (), groups.end ());
+    visit_presentities (sigc::mem_fun (helper, &existing_groups_helper::test));
+    result = helper.groups;
   }
 
   result.insert (_("Family"));
   result.insert (_("Friend"));
+  /* Translator: http://www.ietf.org/rfc/rfc4480.txt proposes several
+     relationships between you and your contact; associate means
+     someone who is at the same "level" than you.
+  */
   result.insert (_("Associate"));
+  /* Translator: http://www.ietf.org/rfc/rfc4480.txt proposes several
+     relationships between you and your contact; assistant means
+     someone who is at a lower "level" than you.
+  */
   result.insert (_("Assistant"));
+  /* Translator: http://www.ietf.org/rfc/rfc4480.txt proposes several
+     relationships between you and your contact; supervisor means
+     someone who is at a higher "level" than you.
+  */
   result.insert (_("Supervisor"));
+  /* Translator: http://www.ietf.org/rfc/rfc4480.txt proposes several
+     relationships between you and your contact; self means yourself.
+  */
   result.insert (_("Self"));
 
   return result;
@@ -201,7 +246,7 @@ Local::Heap::new_presentity (const std::string name,
 
     if (!questions.handle_request (&request)) {
 
-    // FIXME: better error reporting
+      // FIXME: better error reporting
 #ifdef __GNUC__
       std::cout << "Unhandled form request in "
 		<< __PRETTY_FUNCTION__ << std::endl;
@@ -210,31 +255,64 @@ Local::Heap::new_presentity (const std::string name,
   }
 }
 
+struct push_presence_helper
+{
+  push_presence_helper (const std::string uri_,
+			const std::string presence_): uri(uri_),
+						      presence(presence_)
+  {}
+
+  bool test (Local::PresentityPtr presentity)
+  {
+    if (presentity->get_uri () == uri) {
+
+      presentity->set_presence (presence);
+    }
+
+    return true;
+  }
+
+  const std::string uri;
+  const std::string presence;
+};
 
 void
 Local::Heap::push_presence (const std::string uri,
 			    const std::string presence)
 {
-  for (iterator iter = begin ();
-       iter != end ();
-       ++iter) {
+  push_presence_helper helper(uri, presence);
 
-    if ((*iter)->get_uri () == uri)
-      (*iter)->set_presence (presence);
-  }
+  visit_presentities (sigc::mem_fun (helper, &push_presence_helper::test));
 }
 
+struct push_status_helper
+{
+  push_status_helper (const std::string uri_,
+		      const std::string status_): uri(uri_),
+						  status(status_)
+  {}
+
+  bool test (Local::PresentityPtr presentity)
+  {
+    if (presentity->get_uri () == uri) {
+
+      presentity->set_status (status);
+    }
+
+    return true;
+  }
+
+  const std::string uri;
+  const std::string status;
+};
+
 void
 Local::Heap::push_status (const std::string uri,
 			  const std::string status)
 {
-  for (iterator iter = begin ();
-       iter != end ();
-       ++iter) {
+  push_status_helper helper(uri, status);
 
-    if ((*iter)->get_uri () == uri)
-      (*iter)->set_status (status);
-  }
+  visit_presentities (sigc::mem_fun (helper, &push_status_helper::test));
 }
 
 
@@ -245,7 +323,7 @@ Local::Heap::push_status (const std::string uri,
 void
 Local::Heap::add (xmlNodePtr node)
 {
-  gmref_ptr<Presentity> presentity (new Presentity (core, node));
+  PresentityPtr presentity (new Presentity (core, doc, node));
 
   common_add (presentity);
 }
@@ -258,8 +336,8 @@ Local::Heap::add (const std::string name,
 {
   xmlNodePtr root = NULL;
 
-  root = xmlDocGetRootElement (doc);
-  gmref_ptr<Presentity> presentity (new Presentity (core, name, uri, groups));
+  root = xmlDocGetRootElement (doc.get ());
+  PresentityPtr presentity (new Presentity (core, doc, name, uri, groups));
 
   xmlAddChild (root, presentity->get_node ());
 
@@ -269,7 +347,7 @@ Local::Heap::add (const std::string name,
 
 
 void
-Local::Heap::common_add (gmref_ptr<Presentity> presentity)
+Local::Heap::common_add (PresentityPtr presentity)
 {
   gmref_ptr<Ekiga::PresenceCore> presence_core = core.get ("presence-core");
 
@@ -290,7 +368,7 @@ Local::Heap::save () const
   xmlChar *buffer = NULL;
   int size = 0;
 
-  xmlDocDumpMemory (doc, &buffer, &size);
+  xmlDocDumpMemory (doc.get (), &buffer, &size);
 
   gm_conf_set_string (KEY, (const char *)buffer);
 
@@ -305,52 +383,43 @@ Local::Heap::new_presentity_form_submitted (bool submitted,
   if (!submitted)
     return;
 
-  try {
+  gmref_ptr<Ekiga::PresenceCore> presence_core = core.get ("presence-core");
+  const std::string name = result.text ("name");
+  const std::string good_uri = result.hidden ("good-uri");
+  std::string uri;
+  const std::set<std::string> groups = result.editable_set ("groups");
 
-    gmref_ptr<Ekiga::PresenceCore> presence_core = core.get ("presence-core");
-    const std::string name = result.text ("name");
-    const std::string good_uri = result.hidden ("good-uri");
-    std::string uri;
-    const std::set<std::string> groups = result.editable_set ("groups");
+  if (good_uri == "yes")
+    uri = result.hidden ("uri");
+  else
+    uri = result.text ("uri");
 
-    if (good_uri == "yes")
-      uri = result.hidden ("uri");
+  size_t pos = uri.find_first_of (' ');
+  if (pos != std::string::npos)
+    uri = uri.substr (0, pos);
+  if (presence_core->is_supported_uri (uri)
+      && !has_presentity_with_uri (uri)) {
+
+    add (name, uri, groups);
+    save ();
+  } else {
+
+    Ekiga::FormRequestSimple request(sigc::mem_fun (this, &Local::Heap::new_presentity_form_submitted));
+
+    result.visit (request);
+    if (!presence_core->is_supported_uri (uri))
+      request.error (_("You supplied an unsupported address"));
     else
-      uri = result.text ("uri");
+      request.error (_("You already have a contact with this address!"));
 
-    size_t pos = uri.find_first_of (' ');
-    if (pos != std::string::npos)
-      uri = uri.substr (0, pos);
-    if (presence_core->is_supported_uri (uri)
-	&& !has_presentity_with_uri (uri)) {
+    if (!questions.handle_request (&request)) {
 
-      add (name, uri, groups);
-      save ();
-    } else {
-
-      Ekiga::FormRequestSimple request(sigc::mem_fun (this, &Local::Heap::new_presentity_form_submitted));
-
-      result.visit (request);
-      if (!presence_core->is_supported_uri (uri))
-	request.error (_("You supplied an unsupported address"));
-      else
-	request.error (_("You already have a contact with this address!"));
-
-      if (!questions.handle_request (&request)) {
-
-	// FIXME: better error handling
+      // FIXME: better error handling
 #ifdef __GNUC__
-	std::cout << "Unhandled form request in "
-		  << __PRETTY_FUNCTION__ << std::endl;
+      std::cout << "Unhandled form request in "
+		<< __PRETTY_FUNCTION__ << std::endl;
 #endif
-      }
     }
-  } catch (Ekiga::Form::not_found) {
-
-#ifdef __GNUC__
-    std::cerr << "Invalid form submitted to "
-	      << __PRETTY_FUNCTION__ << std::endl;
-#endif
   }
 }
 
@@ -373,6 +442,24 @@ Local::Heap::on_rename_group (std::string name)
   }
 }
 
+struct rename_group_form_submitted_helper
+{
+  rename_group_form_submitted_helper (const std::string old_name_,
+				      const std::string new_name_):
+    old_name(old_name_),
+    new_name(new_name_)
+  {}
+
+  const std::string old_name;
+  const std::string new_name;
+
+  bool rename_group (Local::PresentityPtr presentity)
+  {
+    presentity->rename_group (old_name, new_name);
+    return true;
+  }
+};
+
 void
 Local::Heap::rename_group_form_submitted (std::string old_name,
 					  bool submitted,
@@ -381,23 +468,11 @@ Local::Heap::rename_group_form_submitted (std::string old_name,
   if (!submitted)
     return;
 
-  try {
-    const std::string new_name = result.text ("name");
+  const std::string new_name = result.text ("name");
 
-    if ( !new_name.empty () && new_name != old_name) {
+  if ( !new_name.empty () && new_name != old_name) {
 
-      for (iterator iter = begin ();
-	   iter != end ();
-	   ++iter) {
-
-	(*iter)->rename_group (old_name, new_name);
-      }
-    }
-  } catch (Ekiga::Form::not_found) {
-
-#ifdef __GNUC__
-    std::cerr << "Invalid form submitted to "
-	      << __PRETTY_FUNCTION__ << std::endl;
-#endif
+    rename_group_form_submitted_helper helper (old_name, new_name);
+    visit_presentities (sigc::mem_fun (helper, &rename_group_form_submitted_helper::rename_group));
   }
 }
