@@ -122,6 +122,8 @@ Opal::Account::Account (Ekiga::ServiceCore & _core,
   else
     type = Account::H323;
 
+  limited = (name.find ("%limit") != std::string::npos);
+
   registration_event.connect (sigc::mem_fun (this, &Opal::Account::on_registration_event));
 }
 
@@ -145,7 +147,10 @@ Opal::Account::Account (Ekiga::ServiceCore & _core,
   protocol_name = (t == H323) ? "H323" : "SIP";
   host = _host;
   username = _username;
-  auth_username = _auth_username;
+  if (!_auth_username.empty())
+    auth_username = _auth_username;
+  else
+    auth_username = _username;
   password = _password;
   timeout = _timeout;
   type = t;
@@ -192,7 +197,10 @@ const std::string Opal::Account::get_aor () const
 {
   std::stringstream str;
 
-  str << (protocol_name == "SIP" ? "sip:" : "h323:") << username << "@" << host;
+  str << (protocol_name == "SIP" ? "sip:" : "h323:") << username;
+
+  if (username.find ("@") == string::npos)
+    str << "@" << host;
 
   return str.str ();
 }
@@ -274,6 +282,12 @@ bool Opal::Account::is_enabled () const
 }
 
 
+bool Opal::Account::is_limited () const
+{
+  return limited;
+}
+
+
 bool Opal::Account::is_active () const
 {
   return active;
@@ -427,7 +441,8 @@ void Opal::Account::on_edit_form_submitted (bool submitted,
     password = new_password;
     timeout = new_timeout;
     enabled = new_enabled;
-    enable ();
+    if (enabled)
+      enable ();
 
     updated.emit ();
     trigger_saving.emit ();
