@@ -96,7 +96,7 @@ static void on_core_updated (gpointer data);
  * BEHAVIOR     : 
  * PRE          : The given GtkWidget pointer must be an SearchBook GObject.
  */
-static void on_source_added (gmref_ptr<Ekiga::Source> source,
+static void on_source_added (Ekiga::SourcePtr source,
 			     gpointer data);
 
 
@@ -104,8 +104,8 @@ static void on_source_added (gmref_ptr<Ekiga::Source> source,
  * BEHAVIOR     : 
  * PRE          : The given GtkWidget pointer must be an SearchBook GObject.
  */
-static bool visit_books (gmref_ptr<Ekiga::Book> book,
-			 gmref_ptr<Ekiga::Source> source,
+static bool visit_books (Ekiga::BookPtr book,
+			 Ekiga::SourcePtr source,
 			 gpointer data);
 
 
@@ -114,8 +114,8 @@ static bool visit_books (gmref_ptr<Ekiga::Book> book,
  * BEHAVIOR     : Add a view of the Book in the AddressBookWindow.
  * PRE          : The given GtkWidget pointer must be an SearchBook GObject.
  */
-static void on_book_added (gmref_ptr<Ekiga::Source> source,
-			   gmref_ptr<Ekiga::Book> book,
+static void on_book_added (Ekiga::SourcePtr source,
+			   Ekiga::BookPtr book,
                            gpointer data);
 
 
@@ -124,8 +124,8 @@ static void on_book_added (gmref_ptr<Ekiga::Source> source,
  * BEHAVIOR     : Remove the view of the Book from the AddressBookWindow.
  * PRE          : The given GtkWidget pointer must be an SearchBook GObject.
  */
-static void on_book_removed (gmref_ptr<Ekiga::Source> source,
-			     gmref_ptr<Ekiga::Book> book,
+static void on_book_removed (Ekiga::SourcePtr source,
+			     Ekiga::BookPtr book,
                              gpointer data);
 
 
@@ -134,8 +134,8 @@ static void on_book_removed (gmref_ptr<Ekiga::Source> source,
  * BEHAVIOR     : Update the Book in the AddressBookWindow.
  * PRE          : The given GtkWidget pointer must be an SearchBook GObject.
  */
-static void on_book_updated (gmref_ptr<Ekiga::Source> source,
-			     gmref_ptr<Ekiga::Book> book,
+static void on_book_updated (Ekiga::SourcePtr source,
+			     Ekiga::BookPtr book,
                              gpointer data);
 
 /* DESCRIPTION  : Called when the ContactCore has a form request
@@ -187,7 +187,7 @@ static gint on_book_clicked (GtkWidget *tree_view,
  * PRE          : /
  */
 static void addressbook_window_add_book (AddressBookWindow * self,
-                                         gmref_ptr<Ekiga::Book> book);
+                                         Ekiga::BookPtr book);
 
 
 /* DESCRIPTION  : /
@@ -196,7 +196,7 @@ static void addressbook_window_add_book (AddressBookWindow * self,
  * PRE          : /
  */
 static void addressbook_window_update_book (AddressBookWindow *self,
-                                            gmref_ptr<Ekiga::Book> book);
+                                            Ekiga::BookPtr book);
 
 
 /* DESCRIPTION  : /
@@ -204,7 +204,7 @@ static void addressbook_window_update_book (AddressBookWindow *self,
  * PRE          : /
  */
 static void addressbook_window_remove_book (AddressBookWindow *self,
-                                            gmref_ptr<Ekiga::Book> book);
+                                            Ekiga::BookPtr book);
 
 
 /* DESCRIPTION  : /
@@ -215,7 +215,7 @@ static void addressbook_window_remove_book (AddressBookWindow *self,
  * PRE          : /
  */
 static gboolean find_iter_for_book (AddressBookWindow *addressbook_window,
-                                    gmref_ptr<Ekiga::Book> book,
+                                    Ekiga::BookPtr book,
                                     GtkTreeIter *iter);
 
 
@@ -251,7 +251,7 @@ on_core_updated (gpointer data)
 
 
 static void
-on_source_added (gmref_ptr<Ekiga::Source> source,
+on_source_added (Ekiga::SourcePtr source,
 		 gpointer data)
 {
   source->visit_books (sigc::bind (sigc::ptr_fun (visit_books),
@@ -259,8 +259,8 @@ on_source_added (gmref_ptr<Ekiga::Source> source,
 }
 
 
-static bool visit_books (gmref_ptr<Ekiga::Book> book,
-			 gmref_ptr<Ekiga::Source> source,
+static bool visit_books (Ekiga::BookPtr book,
+			 Ekiga::SourcePtr source,
 			 gpointer data)
 {
   on_book_added (source, book, data);
@@ -270,8 +270,8 @@ static bool visit_books (gmref_ptr<Ekiga::Book> book,
 
 
 static void
-on_book_added (gmref_ptr<Ekiga::Source> /*source*/,
-	       gmref_ptr<Ekiga::Book> book,
+on_book_added (Ekiga::SourcePtr /*source*/,
+	       Ekiga::BookPtr book,
                gpointer data)
 {
   addressbook_window_add_book (ADDRESSBOOK_WINDOW (data), book);
@@ -279,8 +279,8 @@ on_book_added (gmref_ptr<Ekiga::Source> /*source*/,
 
 
 static void
-on_book_removed (gmref_ptr<Ekiga::Source> /*source*/,
-		 gmref_ptr<Ekiga::Book> book,
+on_book_removed (Ekiga::SourcePtr /*source*/,
+		 Ekiga::BookPtr book,
                  gpointer data)
 {
   addressbook_window_remove_book (ADDRESSBOOK_WINDOW (data), book);
@@ -288,8 +288,8 @@ on_book_removed (gmref_ptr<Ekiga::Source> /*source*/,
 
 
 static void
-on_book_updated (gmref_ptr<Ekiga::Source> /*source*/,
-		 gmref_ptr<Ekiga::Book> book,
+on_book_updated (Ekiga::SourcePtr /*source*/,
+		 Ekiga::BookPtr book,
                  gpointer data)
 {
   addressbook_window_update_book (ADDRESSBOOK_WINDOW (data), book);
@@ -422,7 +422,7 @@ on_book_clicked (GtkWidget *tree_view,
 /* Implementation of the private functions */
 static void
 addressbook_window_add_book (AddressBookWindow *self,
-                             gmref_ptr<Ekiga::Book> book)
+                             Ekiga::BookPtr book)
 {
   GtkTreeIter iter;
   GtkTreeModel *store = NULL;
@@ -449,7 +449,7 @@ addressbook_window_add_book (AddressBookWindow *self,
   gtk_tree_store_set (GTK_TREE_STORE (store), &iter,
                       COLUMN_PIXBUF, icon, 
                       COLUMN_NAME, book->get_name ().c_str (),
-                      COLUMN_BOOK_POINTER, &*book, 
+                      COLUMN_BOOK_POINTER, book.get (), 
                       COLUMN_VIEW, view,
                       -1);
 
@@ -465,7 +465,7 @@ addressbook_window_add_book (AddressBookWindow *self,
 
 static void
 addressbook_window_update_book (AddressBookWindow *self,
-                                gmref_ptr<Ekiga::Book> book)
+                                Ekiga::BookPtr book)
 {
   GtkTreeIter iter;
   GtkTreeModel *store = NULL;
@@ -480,7 +480,7 @@ addressbook_window_update_book (AddressBookWindow *self,
 
 static void
 addressbook_window_remove_book (AddressBookWindow *self,
-                                gmref_ptr<Ekiga::Book> book)
+                                Ekiga::BookPtr book)
 {
   GtkTreeIter iter;
   gint page = -1;
@@ -517,7 +517,7 @@ addressbook_window_remove_book (AddressBookWindow *self,
 
 static gboolean
 find_iter_for_book (AddressBookWindow *self,
-                    gmref_ptr<Ekiga::Book> book,
+                    Ekiga::BookPtr book,
                     GtkTreeIter *iter)
 {
   Ekiga::Book *book_iter = NULL;
@@ -533,7 +533,7 @@ find_iter_for_book (AddressBookWindow *self,
                           COLUMN_BOOK_POINTER, &book_iter,
                           -1);
 
-      if (&*book == book_iter) {
+      if (book.get () == book_iter) {
 
         break;
       }
@@ -750,6 +750,9 @@ addressbook_window_new (Ekiga::ContactCore &core)
                     G_CALLBACK (on_notebook_realize), self);
   gtk_paned_add2 (GTK_PANED (hpaned), self->priv->notebook);
 
+  conn = core.source_added.connect (sigc::bind (sigc::ptr_fun (on_source_added), (gpointer) self));
+  self->priv->connections.push_back (conn);
+
   conn = core.book_updated.connect (sigc::bind (sigc::ptr_fun (on_book_updated),
                                                 (gpointer) self));
   self->priv->connections.push_back (conn);
