@@ -1,6 +1,6 @@
 
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2006 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -61,29 +61,26 @@ gnomemeeting_stock_icons_init (void)
 	{
 	        { GM_STOCK_COLOR_BRIGHTNESS_CONTRAST, gm_color_brightness_contrast_stock_data },
 
-		{ GM_STOCK_STATUS_FREEFORCHAT, gm_status_freeforchat_stock_data },
-		{ GM_STOCK_STATUS_RINGING, gm_status_ringing_stock_data },
-
 		{ GM_STOCK_STATUS_ONLINE, gm_status_online_stock_data },
 		{ GM_STOCK_STATUS_OFFLINE, gm_status_offline_stock_data },
 		{ GM_STOCK_STATUS_UNKNOWN, gm_status_unknown_stock_data },
 		{ GM_STOCK_STATUS_AWAY, gm_status_away_stock_data },
 		{ GM_STOCK_STATUS_DND, gm_status_dnd_stock_data },
 		{ GM_STOCK_STATUS_INACALL, gm_status_inacall_stock_data_16 },
+		{ GM_STOCK_STATUS_RINGING, gm_status_ringing_stock_data_16 },
 
-		{ GM_STOCK_REMOTE_CONTACT, gm_remote_contact_stock_data},
-		{ GM_STOCK_LOCAL_CONTACT, gm_local_contact_stock_data},
+		{ GM_STOCK_REMOTE_OBJECT, gm_remote_contact_stock_data},
+		{ GM_STOCK_LOCAL_OBJECT, gm_local_contact_stock_data},
 		{ GM_STOCK_MESSAGE, gm_message_stock_data},
 		{ GM_STOCK_CALL_PLACED, gm_call_placed_stock_data},
 		{ GM_STOCK_CALL_MISSED, gm_call_missed_stock_data},
 		{ GM_STOCK_CALL_RECEIVED, gm_call_received_stock_data},
+		{ GM_STOCK_CALL_TRANSFER, gm_call_transfer_stock_data},
 
 		{ GM_STOCK_PHONE_HANG_UP_16, gm_phone_hang_up_stock_data_16},
 		{ GM_STOCK_PHONE_PICK_UP_16, gm_phone_pick_up_stock_data_16},
 		{ GM_STOCK_PHONE_HANG_UP_24, gm_phone_hang_up_stock_data_24},
 		{ GM_STOCK_PHONE_PICK_UP_24, gm_phone_pick_up_stock_data_24},
-
-	        { GM_STOCK_ADDRESSBOOK, gm_addressbook_16_stock_data },
 	};
 
         typedef struct 
@@ -96,8 +93,6 @@ gnomemeeting_stock_icons_init (void)
 	static const GmThemeIcon theme_builtins[] =
 	{
 		{ GM_ICON_ADD_CONTACT, 24, gm_add_contact_24_stock_data},
-	        { GM_ICON_ADDRESSBOOK, 16, gm_addressbook_16_stock_data },
-	        { GM_ICON_ADDRESSBOOK, 24, gm_addressbook_24_stock_data },
 	        { GM_ICON_AUDIO_VOLUME_HIGH, 16, gm_audio_volume_high_16_stock_data },
 		{ GM_ICON_BRIGHTNESS, 16, gm_brightness_16_stock_data},
 		{ GM_ICON_CAMERA_VIDEO, 16, gm_camera_video_16_stock_data },
