@@ -63,7 +63,7 @@
 
 #undef GTK_DISABLE_DEPRECATED
 #ifdef HAVE_GNOME
-#include <gnome.h>
+#include <libgnome/gnome-help.h>
 #endif
 
 
@@ -200,7 +200,7 @@ GNU GPL for all the rest of the software thus combined.")
   gtk_show_about_dialog (GTK_WINDOW (parent_window),
 		"name", "Ekiga",
 		"version", VERSION,
-                "copyright", "Copyright © 2000-2009 Damien Sandras"
+                "copyright", "Copyright © 2000-2009 Damien Sandras",
 		"authors", authors,
 		"documenters", documenters,
 		"translator-credits", translator_credits,
